@@ -1,6 +1,6 @@
 #!/bin/bash
 # Shockvoice installer written by
-# Andre Zurmuehlen
+# Andre Liersch
 # kobayashi@shockvoice.org
 # update 15.03.2010 - additional features in config.xml - added SOAP question
 # created on 29.09.2009
@@ -48,6 +48,7 @@ file="service_start"
     cd $appdir
     if [ -e "$file" ]; then    
     mv $file service_start.ORIG
+    echo "Found old service_start file renaming it!"
     fi
     touch "$file"
     chmod 0740 "$file"
@@ -108,6 +109,7 @@ file="service_stop"
     cd $appdir
     if [ -e "$file" ]; then
     mv $file service_stop.ORIG
+    echo "Found old service_stop file renaming it!"
     fi
     touch "$file"
     chmod 0740 "$file"
@@ -137,6 +139,7 @@ file1="config.xml"
     cd $appdir
     if [ -e "$file1" ]; then
     mv $file1 config.xml.ORIG
+    echo "Found old config.xml renaming it!"
     fi
     touch "$file1"
     chmod 0740 "$file1"
